/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SortableBindingDirective } from "./binding.directive";
import { DraggableDirective } from "./draggable.directive";
import { ItemTemplateDirective, PlaceholderTemplateDirective } from "./item-template.directive";
import { SortableComponent } from "./sortable.component";
/**
 * Use this utility array to access all `@progress/kendo-angular-sortable`-related components and directives in a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_SORTABLE } from '@progress/kendo-angular-sortable';
 *
 * @Component({
 *   selector: 'my-app',
 *   standalone: true,
 *   imports: [KENDO_SORTABLE],
 *   template: `
 *      <kendo-sortable [kendoSortableBinding]="items">
 *      </kendo-sortable>
 *   `
 * })
 *
 * export class AppComponent {
 *    public items = ['Item 1', 'Item 2', 'Item 3'];
 * }
 * ```
 */
export declare const KENDO_SORTABLE: readonly [typeof SortableComponent, typeof DraggableDirective, typeof PlaceholderTemplateDirective, typeof ItemTemplateDirective, typeof SortableBindingDirective];
