/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from './preventable-event';
/**
 * Represents the arguments for the `SortableComponent` `dataAdd` event.
 */
export class DataAddEvent extends PreventableEvent {
    /**
     * Specifies the index of the data item.
     */
    index;
    /**
     * Specifies the data item to add.
     */
    dataItem;
    /**
     * @hidden
     */
    constructor(options) {
        super();
        Object.assign(this, options);
    }
}
/**
 * Represents the arguments for the `SortableComponent` `dataRemove` event.
 */
export class DataRemoveEvent extends PreventableEvent {
    /**
     * Specifies the index of the data item.
     */
    index;
    /**
     * Specifies the data item to remove.
     */
    dataItem;
    /**
     * @hidden
     */
    constructor(options) {
        super();
        Object.assign(this, options);
    }
}
/**
 * Represents the arguments for the `SortableComponent` `dataMove` event.
 */
export class DataMoveEvent extends PreventableEvent {
    /**
     * Specifies the index of the data item.
     */
    index;
    /**
     * Specifies the old index of the data item.
     */
    oldIndex;
    /**
     * Specifies the data item to move.
     */
    dataItem;
    /**
     * @hidden
     */
    constructor(options) {
        super();
        Object.assign(this, options);
    }
}
