/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from './preventable-event';
/**
 * Represents the arguments for the `dragStart` event.
 */
export class DragStartEvent extends PreventableEvent {
    /**
     * Specifies the index of the draggable item.
     */
    index;
    /**
     * Specifies the previous index of the draggable item.
     * This property is used for the `dragEnd and `dragOver` events to determine the original position of the item before dragging.
     * It doesn't apply to the `dragStart` event as there is no previous position at that point.
     */
    oldIndex;
    /**
     * @hidden
     */
    constructor(options) {
        super();
        Object.assign(this, options);
    }
}
/**
 * Represents the arguments for the `dragOver` event.
 */
export class DragOverEvent extends DragStartEvent {
}
/**
 * Represents the arguments for the `dragEnd` event.
 */
export class DragEndEvent extends DragOverEvent {
}
