/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from './preventable-event';
import { SortableEvent } from './sortable-event-args.interface';
/**
 * Represents the arguments for the `dragStart` event.
 */
export declare class DragStartEvent extends PreventableEvent implements SortableEvent {
    /**
     * Specifies the index of the draggable item.
     */
    index: number;
    /**
     * Specifies the previous index of the draggable item.
     * This property is used for the `dragEnd and `dragOver` events to determine the original position of the item before dragging.
     * It doesn't apply to the `dragStart` event as there is no previous position at that point.
     */
    oldIndex: number;
    /**
     * @hidden
     */
    constructor(options: any);
}
/**
 * Represents the arguments for the `dragOver` event.
 */
export declare class DragOverEvent extends DragStartEvent {
}
/**
 * Represents the arguments for the `dragEnd` event.
 */
export declare class DragEndEvent extends DragOverEvent {
}
